<?php
/**
 * @copyright Copyright (c) 2021 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\CSPEditor\Settings;

use OCA\CSPEditor\AppInfo\Application;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\AppFramework\Services\IInitialState;
use OCP\IConfig;
use OCP\Settings\ISettings;
use OCP\Util;

class Admin implements ISettings {
	private IConfig $config;
	private IInitialState $initialState;

	public function __construct(IConfig $config, IInitialState $initialState) {
		$this->config = $config;
		$this->initialState = $initialState;
	}

	public function getForm(): TemplateResponse {
		$config = $this->config->getAppValue(Application::APP_NAME, 'customCSP', '[]');
		$debug = $this->config->getSystemValueBool('debug', false);

		$this->initialState->provideInitialState('customCSP', $config);
		$this->initialState->provideInitialState('debug', $debug);
		Util::addScript(Application::APP_NAME, 'csp_editor-admin-settings');

		return new TemplateResponse(Application::APP_NAME, 'admin');
	}

	public function getSection(): string {
		return 'additional';
	}

	public function getPriority(): int {
		return 80;
	}
}
